@@ -10,10 +10,13 @@ use base 'Mojo::Base';
 # No imports to make subclassing a bit easier
 require Carp;
 
+use Mojo::Home;
 use Mojo::Transaction;
 
+__PACKAGE__->attr('home', chained => 1, default => sub { Mojo::Home->new });
+
 # Oh, so they have internet on computers now!
-our $VERSION = '0.8008';
+our $VERSION = '0.8009';
 
 sub build_tx { return Mojo::Transaction->new }
 
@@ -56,6 +59,15 @@ tradeoff.
 
 For userfriendly documentation see L<Mojo::Manual>.
 
+=head1 ATTRIBUTES
+
+L<Mojo> implements the following attributes.
+
+=head2 C<home>
+
+    my $home = $mojo->home;
+    $mojo    = $mojo->home(Mojo::Home->new);
+
 =head1 METHODS
 
 L<Mojo> inherits all methods from L<Mojo::Base> and implements the following
@@ -124,6 +136,8 @@ Andy Grundman
 
 Aristotle Pagaltzis
 
+Ask Bjoern Hansen
+
 Audrey Tang
 
 Christian Hansen
