@@ -7,17 +7,16 @@ use warnings;
 
 use base 'Mojo::Server';
 
-use Mojo::Transaction;
 use IO::Select;
 
-__PACKAGE__->attr('non_parsed_header', chained => 1, default => sub { 0 });
+__PACKAGE__->attr('nph', chained => 1, default => 0);
 
 # Lisa, you're a Buddhist, so you believe in reincarnation.
 # Eventually, Snowball will be reborn as a higher lifeform... like a snowman.
 sub run {
     my $self = shift;
 
-    my $tx  = Mojo::Transaction->new;
+    my $tx  = $self->build_tx_cb->($self);
     my $req = $tx->req;
 
     # Environment
@@ -33,15 +32,26 @@ sub run {
     }
 
     # Handle
-    $self->handler->($self, $tx);
+    $self->handler_cb->($self, $tx);
 
     my $res = $tx->res;
 
     # Response start line
     my $offset = 0;
-    if ($self->non_parsed_header) {
-        while ($offset < $res->start_line_length) {
+    if ($self->nph) {
+        while (1) {
             my $chunk = $res->get_start_line_chunk($offset);
+
+            # No start line yet, try again
+            unless (defined $chunk) {
+                sleep 1;
+                next;
+            }
+
+            # End of start line
+            last unless length $chunk;
+
+            # Start line
             my $written = STDOUT->syswrite($chunk);
             $offset += $written;
         }
@@ -50,11 +60,22 @@ sub run {
     # Response headers
     my $code = $res->code;
     my $message = $res->message || $res->default_message;
-    $res->headers->header('Status', "$code $message")
-      unless $self->non_parsed_header;
+    $res->headers->header('Status', "$code $message") unless $self->nph;
     $offset = 0;
-    while ($offset < $res->header_length) {
-        my $written = STDOUT->syswrite($res->get_header_chunk($offset));
+    while (1) {
+        my $chunk = $res->get_header_chunk($offset);
+
+        # No headers yet, try again
+        unless (defined $chunk) {
+            sleep 1;
+            next;
+        }
+
+        # End of headers
+        last unless length $chunk;
+
+        # Headers
+        my $written = STDOUT->syswrite($chunk);
         $offset += $written;
     }
 
@@ -103,10 +124,10 @@ L<Mojo::Server::CGI> is a simple and portable CGI implementation.
 L<Mojo::Server::CGI> inherits all attributes from L<Mojo::Server> and
 implements the following new ones.
 
-=head2 C<non_parsed_header>
+=head2 C<nph>
 
-    my $non_parsed_header = $cgi->non_parsed_header;
-    $cgi                  = $cgi->non_parsed_header(1);
+    my $nph = $cgi->nph;
+    $cgi    = $cgi->nph(1);
 
 =head1 METHODS
 
