@@ -11,19 +11,10 @@ use Carp 'croak';
 use IO::Select;
 use IO::Socket;
 
-__PACKAGE__->attr('keep_alive_timeout',
-    chained => 1,
-    default => sub { 15 }
-);
-__PACKAGE__->attr('listen_queue_size',
-    chained => 1,
-    default => sub { SOMAXCONN }
-);
-__PACKAGE__->attr('max_clients', chained => 1, default => sub { 1000 });
-__PACKAGE__->attr('max_keep_alive_requests',
-    chained => 1,
-    default => sub { 100 }
-);
+__PACKAGE__->attr('keep_alive_timeout', chained => 1, default => 15);
+__PACKAGE__->attr('listen_queue_size', chained => 1, default => SOMAXCONN);
+__PACKAGE__->attr('max_clients', chained => 1, default => 1000);
+__PACKAGE__->attr('max_keep_alive_requests', chained => 1, default => 100);
 __PACKAGE__->attr('port', chained => 1, default => 3000);
 
 sub accept_lock { return 1 }
@@ -36,11 +27,14 @@ sub listen {
     # Create socket
     my $port = $self->port;
     $self->{listen} ||= IO::Socket::INET->new(
-        Blocking  => 0,
         Listen    => $self->listen_queue_size,
         LocalPort => $port,
-        Reuse     => 1
+        Proto     => 'tcp',
+        ReuseAddr => 1,
+        Type      => SOCK_STREAM
     ) or croak "Can't create listen socket: $!";
+
+    # Non blocking
     $self->{listen}->blocking(0);
 
     # Friendly message
@@ -81,6 +75,12 @@ sub spin {
     elsif (@$read) { $self->_read($read) }
 }
 
+sub _drop_connection {
+    my ($self, $name) = @_;
+    delete $self->{_reverse}->{$self->{_connections}->{$name}};
+    delete $self->{_connections}->{$name};
+}
+
 sub _prepare_connections {
     my $self = shift;
 
@@ -100,6 +100,7 @@ sub _prepare_connections {
         # Connected
         $accept->{socket}->blocking(0);
         next unless my $name = $self->_socket_name($accept->{socket});
+        $self->{_reverse}->{$accept->{socket}} = $name;
         $self->{_connections}->{$name} = $accept;
     }
     $self->{_accepted} = [@accepted];
@@ -128,7 +129,7 @@ sub _prepare_select {
         # Keep alive timeout
         my $timeout = time - $connection->{time};
         if ($self->keep_alive_timeout < $timeout) {
-            delete $self->{_connections}->{$name};
+            $self->_drop_connection($name);
             next;
         }
 
@@ -137,7 +138,8 @@ sub _prepare_select {
 
             # Keep alive request limit
             if ($connection->{requests} >= $self->max_keep_alive_requests) {
-                delete $self->{_connections}->{$name};
+                $self->_drop_connection($name);
+                
             }
 
             # Keep alive
@@ -170,7 +172,7 @@ sub _prepare_transactions {
 
         # Cleanup dead connection
         unless ($connection->{socket}->connected) {
-            delete $self->{_connections}->{$name};
+            $self->_drop_connection($name);
             next;
         }
 
@@ -183,6 +185,16 @@ sub _prepare_transactions {
         # Writing
         if ($tx->is_state('write')) {
 
+            # Connection header
+            unless ($tx->res->headers->connection) {
+                if ($tx->keep_alive) {
+                    $tx->res->headers->connection('Keep-Alive');
+                }
+                else {
+                    $tx->res->headers->connection('Close');
+                }
+            }
+
             # Ready for next state
             $tx->state('write_start_line');
             $tx->{_to_write} = $tx->res->start_line_length;
@@ -209,14 +221,14 @@ sub _prepare_transactions {
             if (defined $tx->continued && $tx->continued == 0) {
                 $tx->continued(1);
                 $tx->state('read');
-                $tx->state('done') unless $tx->res->code == 100;
+                $tx->done unless $tx->res->code == 100;
                 $tx->res->code(0);
                 next;
             }
 
             # Done
             delete $connection->{tx};
-            delete $self->{_connections}->{$name} unless $tx->keep_alive;
+            $self->_drop_connection($name) unless $tx->keep_alive;
         }
     }
 }
@@ -247,9 +259,10 @@ sub _read {
         $tx->connection($socket);
         $tx->state('read');
         $connection->{requests}++;
+        $tx->kept_alive(1) if $connection->{requests} > 1;
 
         # Last keep alive request?
-        $tx->res->headers->connection('close')
+        $tx->res->headers->connection('Close')
           if $connection->{requests} >= $self->max_keep_alive_requests;
     }
 
@@ -261,7 +274,7 @@ sub _read {
 
     # Read error
     unless (defined $read) {
-        delete $self->{_connections}->{$name};
+        $self->_drop_connection($name);
         return 1;
     }
 
@@ -290,8 +303,19 @@ sub _read {
 
 sub _socket_name {
     my ($self, $s) = @_;
+
+    # Cache
+    return $self->{_reverse}->{$s} if $self->{_reverse}->{$s};
+
+    # Connected?
     return undef unless $s->connected;
-    return join ':', $s->sockaddr, $s->sockport, $s->peeraddr, $s->peerport;
+
+    my $n = join ':', $s->sockaddr, $s->sockport, $s->peeraddr, $s->peerport;
+
+    # Temporary workaround for win32 weirdness
+    $n =~ s/[^\w]/x/gi;
+
+    return $n;
 }
 
 sub _write {
@@ -410,4 +434,4 @@ implements the following new ones.
 
     $daemon->spin;
 
-=cut
\ No newline at end of file
+=cut
