@@ -9,7 +9,9 @@ use base 'Mojo::Base';
 
 # Don't kid yourself, Jimmy. If a cow ever got the chance,
 # he'd eat you and everyone you care about!
-__PACKAGE__->attr('state', chained => 1, default => sub { 'start' });
+__PACKAGE__->attr('state', chained => 1, default => 'start');
+
+sub done { shift->state('done') }
 
 sub error {
     my ($self, $message) = @_;
@@ -20,6 +22,8 @@ sub error {
 
 sub has_error { return defined shift->{error} }
 
+sub is_done { return shift->state eq 'done' }
+
 sub is_state {
     my ($self, @states) = @_;
     for my $state (@states) { return 1 if $self->state eq $state }
@@ -58,10 +62,18 @@ L<Mojo::Stateful> is a base class for state keeping instances.
 L<Mojo::Stateful> inherits all methods from L<Mojo::Base> and implements the
 following new ones.
 
+=head2 C<done>
+
+    $stateful = $stateful->done;
+
 =head2 C<has_error>
 
     my $has_error = $stateful->has_error;
 
+=head2 C<is_done>
+
+    my $done = $stateful->is_done;
+
 =head2 C<is_state>
 
     my $is_state = $stateful->is_state('writing');
