@@ -7,6 +7,7 @@ use warnings;
 
 use base 'Mojo::Base';
 
+use Carp qw/carp croak/;
 use File::Spec;
 use MojoX::Types;
 
@@ -50,7 +51,15 @@ sub render {
     return 0 unless $ext;
 
     my $handler = $self->handler->{$ext};
-    my $result = $handler->($self, $tx, $path);
+
+    # Fallback
+    unless ($handler) {
+        carp qq/No handler for "$ext" files configured/;
+        $handler = $self->handler->{$default};
+        croak 'Need a valid handler for rendering' unless $handler;
+    }
+
+    my $result = $handler->($self, $tx, $path, $options);
 
     return $result if $options->{partial};
 
